ChannelDescription class

A class representing the description of a channel in a CAF file.

Constructors

ChannelDescription({required int channelLabel, required int channelFlags, required List<double> coordinates})

Properties

channelFlags int
The flags of the channel.
final
channelLabel int
The label of the channel.
final
coordinates List<double>
The coordinates of the channel.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Uint8List
Encodes the channel description to a Uint8List.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited