ChannelLayout class
A class representing the layout of channels in a CAF file.
Constructors
-
ChannelLayout({required int channelLayoutTag, required int channelBitmap, required int numberChannelDescriptions, required List<
ChannelDescription> channels})
Properties
- channelBitmap → int
-
The bitmap of the channel layout.
final
- channelLayoutTag → int
-
The tag of the channel layout.
final
-
channels
→ List<
ChannelDescription> -
The list of channel descriptions in the channel layout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numberChannelDescriptions → int
-
The number of channel descriptions in the channel layout.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Uint8List - Encodes the channel layout to a Uint8List.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited