PacketTable class

A class representing a packet table in a CAF file.

Constructors

PacketTable({required PacketTableHeader header, required List<int> entries})

Properties

entries List<int>
The list of entries in the packet table.
final
hashCode int
The hash code for this object.
no setterinherited
The header of the packet table.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Uint8List
Encodes the packet table to a Uint8List.
encodeVarint(int value) List<int>
Encodes an integer to data using variable-length encoding technique (varint) format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited